using System;
using System.Windows.Forms;
using System.Drawing;
using System.Runtime.Serialization;



namespace Syncfusion.Windows.Forms.Diagram.Samples.DiagramTool
{
  public enum LabelTypes : int
  {
    Text,
    Ref,
    Child,
    Label,
    MainLabel
  }
  /// <summary>
  /// Summary description for Class2.
  /// </summary>
  
  [
  Serializable()
  ]
  public class PEPSymbolLabel : Syncfusion.Windows.Forms.Diagram.SymbolLabel

  {
    public PEPSymbolLabel()
    {
      //
      // TODO: Add constructor logic here
      //
      this.FontStyle.Size = 10;
      this.NoClip         = true;
      this.Visible        = true;
      this.HorizontalAlignment = StringAlignment.Center;
    }
    
    /// <summary>
    /// 
    /// </summary>
    /// <param name="container"></param>
    public PEPSymbolLabel(ILabelContainer container) : base(container)
  {
  }

    /// <summary>
    /// 
    /// </summary>
    /// <param name="container"></param>
    /// <param name="txtVal"></param>
    public PEPSymbolLabel(ILabelContainer container, string txtVal) : base(container, txtVal)
  {
  }
    
    public PEPSymbolLabel(SymbolLabel src) : base(src)
  {
  }
    /// <summary>
    /// Serialization constructor for symbol labels.
    /// </summary>
    /// <param name="info">Serialization state information</param>
    /// <param name="context">Streaming context information</param>
    protected PEPSymbolLabel(SerializationInfo info, StreamingContext context) : base(info, context)
    {
      LabelType        = (LabelTypes) info.GetUInt16("labelType");
      ReferencePath    = info.GetString("referencePath");
      ChildProcessName = info.GetString("childProcessName");
    }

    protected override void GetObjectData(SerializationInfo info, StreamingContext context)
    {
      base.GetObjectData(info, context);
      info.AddValue("labelType",        this.labelType);
      info.AddValue("referencePath",    this.referencePath);
      info.AddValue("childProcessName", this.childProcessName);
    }
    
    /// <summary>
    /// Creates a new object that is a copy of the current instance.
    /// </summary>
    /// <returns>Copy of the object this method is invoked against</returns>
    public override object Clone()
    {
      return new PEPSymbolLabel(this);
    }
    
    protected override void OnDoubleClick(NodeMouseEventArgs evtArgs)
    {      
      base.OnDoubleClick(evtArgs);
      if (labelType == LabelTypes.Ref)
      {
        MessageBox.Show("File referenced is " + referencePath);
      }
      else if (labelType == LabelTypes.Child)
      {
        MessageBox.Show("Child process is " + childProcessName);
      }
      else
        MessageBox.Show("Label DblClick");
    }

    private string referencePath = ""; 

    public string ReferencePath
    {
      get
      {
        return referencePath;
      }
      set
      {
        referencePath = value;
      }
    }
    
    private string childProcessName = ""; 

    public string ChildProcessName
    {
      get
      {
        return childProcessName;
      }
      set
      {
        childProcessName = value;
      }
    }

    private LabelTypes labelType;
    
    public LabelTypes LabelType
    {
      get 
      {
        return labelType;
      }
      set 
      {
        labelType = value;
        switch (labelType)
        {
          case LabelTypes.Text :  
            ReadOnly              = false;
            EditStyle.AllowSelect = true;
            WrapText              = true;
            Anchor                = BoxPosition.BottomCenter;
            OffsetY               = -10;
            break;
          case LabelTypes.Ref :  
            ReadOnly              = true;
            EditStyle.AllowSelect = false;
            OffsetX               = -10;
            OffsetY               = 20;
            Anchor                = BoxPosition.TopRight;
            FontStyle.Family      = "Pep dings";
            Text                  = "I";
            break;
          case LabelTypes.Child :  
            ReadOnly              = true;
            EditStyle.AllowSelect = false;
            OffsetX               = -10;
            OffsetY               = -10;
            Anchor                = BoxPosition.BottomRight;
            FontStyle.Family      = "Wingdings";
            Text                  = "";
            break;
          case LabelTypes.Label :  
            ReadOnly              = false;
            EditStyle.AllowSelect = true;
            WrapText              = true;
            Anchor                = BoxPosition.TopLeft;
            OffsetX               = 10;
            OffsetY               = 10;
            break;
          case LabelTypes.MainLabel :  
            ReadOnly              = false;
            EditStyle.AllowSelect = true;
            WrapText              = true;
            Anchor                = BoxPosition.Center;
            OffsetX               = 0;
            OffsetY               = 0;
            break;
        }
      }
    }

	}
}
